=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2014-03-24 14:04:38 +0000
+++ CMakeLists.txt	2014-04-03 16:06:05 +0000
@@ -36,6 +36,7 @@
 add_subdirectory(autopilot)
 add_subdirectory(scope)
 add_subdirectory(data)
+add_subdirectory(po)
 
 # Custom targets for the tests
 add_custom_target (test

=== modified file 'debian/control'
--- debian/control	2014-03-24 19:18:13 +0000
+++ debian/control	2014-04-03 16:06:05 +0000
@@ -4,6 +4,7 @@
 Build-Depends: cmake (>= 2.8.10),
                debhelper (>= 9),
                google-mock,
+               intltool,
                libglib2.0-dev (>= 2.32),
                libubuntu-download-manager-client-dev,
                libubuntu-download-manager-common-dev,

=== added directory 'po'
=== added file 'po/CMakeLists.txt'
--- po/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ po/CMakeLists.txt	2014-04-03 16:06:05 +0000
@@ -0,0 +1,36 @@
+include(FindGettext)
+find_program(GETTEXT_XGETTEXT_EXECUTABLE xgettext)
+find_program(INTLTOOL_UPDATE intltool-update)
+
+set(GETTEXT_PACKAGE ${PROJECT_NAME})
+set(POT_FILE ${GETTEXT_PACKAGE}.pot)
+execute_process(
+    COMMAND cat ${CMAKE_CURRENT_SOURCE_DIR}/LINGUAS
+    OUTPUT_VARIABLE LINGUAS
+    OUTPUT_STRIP_TRAILING_WHITESPACE
+)
+
+# Creates POTFILES
+add_custom_target(POTFILES ALL
+    COMMENT "Generating POTFILES"
+    COMMAND ${CMAKE_CURRENT_SOURCE_DIR}/genpotfiles.sh ${CMAKE_SOURCE_DIR}
+)
+
+# Creates the .pot file containing the translations template
+add_custom_target(${POT_FILE} ALL
+    COMMENT "Generating translation template"
+    COMMAND XGETTEXT="${GETTEXT_XGETTEXT_EXECUTABLE}" srcdir="${CMAKE_CURRENT_SOURCE_DIR}" ${INTLTOOL_UPDATE} --gettext-package ${GETTEXT_PACKAGE} --pot
+    DEPENDS POTFILES
+)
+
+# Builds the binary translations catalog for each language
+# it finds source translations (*.po) for
+foreach(LANG ${LINGUAS})
+    list(APPEND PO_FILES "${LANG}.po")
+    gettext_process_po_files(${LANG} ALL PO_FILES "${LANG}.po")
+    set(INSTALL_DIR ${CMAKE_INSTALL_LOCALEDIR}/${LANG}/LC_MESSAGES)
+    install(FILES ${CMAKE_CURRENT_BINARY_DIR}/${LANG}.gmo
+            DESTINATION ${INSTALL_DIR}
+            RENAME ${DOMAIN}.mo
+    )
+endforeach(LANG)

=== added file 'po/LINGUAS'
=== added file 'po/POTFILES.in'
--- po/POTFILES.in	1970-01-01 00:00:00 +0000
+++ po/POTFILES.in	2014-04-03 16:06:05 +0000
@@ -0,0 +1,1 @@
+scope/click/preview.cpp

=== added file 'po/genpotfiles.sh'
--- po/genpotfiles.sh	1970-01-01 00:00:00 +0000
+++ po/genpotfiles.sh	2014-04-03 16:06:05 +0000
@@ -0,0 +1,6 @@
+#!/bin/sh
+
+sed '/^#/d
+	 s/^[[].*] *//
+	 /^[ 	]*$/d' \
+      "`dirname ${0}`/POTFILES.in" | sed '$!s/$/ \\/' > POTFILES

